@@ -10,15 +10,6 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and limitations under the License.
 
-
-.onAttach <- function(libname, pkgname) {
-  if (interactive()) {
-    packageStartupMessage("The bcmapsdata package is no longer required to be installed for bcmaps to function.")
-    packageStartupMessage(paste0("Layers are now cached as needed to '", data_dir(),"' using the bcdata package."))
-  }
-}
-
-
 bcmaps_env <- new.env(parent = emptyenv())
 
 .onLoad <- function(...) {
